==> jc-1.4.0.tar.gz: javax/print/attribute/standard/JobName.h <==
// public final class javax.print.attribute.standard.JobName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2c49b1290ea91885 javax_print_attribute_TextSyntax
// @dep_class e749b5922c186449 javax_print_attribute_standard_JobName

// header file dependencies
// @dep_header javax_print_attribute_TextSyntax

#include "javax/print/attribute/TextSyntax.h"

#ifndef _JC_javax_print_attribute_standard_JobName_H_
#define _JC_javax_print_attribute_standard_JobName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_JobName$sub_refs	_jc_javax_print_attribute_standard_JobName$sub_refs;
typedef struct _jc_javax_print_attribute_standard_JobName$sub_nonrefs	_jc_javax_print_attribute_standard_JobName$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobName$refs	_jc_javax_print_attribute_standard_JobName$refs;
typedef struct _jc_javax_print_attribute_standard_JobName$nonrefs	_jc_javax_print_attribute_standard_JobName$nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobName$object	_jc_javax_print_attribute_standard_JobName$object;

typedef struct _jc_javax_print_attribute_standard_JobName$fields_struct	_jc_javax_print_attribute_standard_JobName$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_JobName$vmethods	_jc_javax_print_attribute_standard_JobName$vmethods;
typedef const struct _jc_javax_print_attribute_standard_JobName$vtable	_jc_javax_print_attribute_standard_JobName$vtable;
typedef const struct _jc_javax_print_attribute_standard_JobName$vtype	_jc_javax_print_attribute_standard_JobName$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_JobName$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24JobName;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_JobName$fields_struct _jc_javax_print_attribute_standard_JobName$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_JobName$method$_init$cc9f9d14d2541299(_jc_env *, struct _jc_javax_print_attribute_standard_JobName$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *);

// Virtual methods
extern jboolean _jc_javax_print_attribute_standard_JobName$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_standard_JobName$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobName$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_JobName$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_JobName$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_JobName$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_JobName$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_standard_JobName$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_JobName$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobName$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_JobName$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_standard_JobName$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_JobName$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_JobName$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_JobName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_TextSyntax$vmethods	javax_print_attribute_TextSyntax;
	_jc_javax_print_attribute_standard_JobName$vmethods	javax_print_attribute_standard_JobName;
};

// Vtype
struct _jc_javax_print_attribute_standard_JobName$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_JobName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobName$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobName$refs {
    _jc_javax_print_attribute_standard_JobName$sub_refs	javax_print_attribute_standard_JobName;
    _jc_javax_print_attribute_TextSyntax$sub_refs	javax_print_attribute_TextSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_TextSyntax$sub_nonrefs	javax_print_attribute_TextSyntax;
    _jc_javax_print_attribute_standard_JobName$sub_nonrefs	javax_print_attribute_standard_JobName;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_JobName$object {
	_jc_javax_print_attribute_standard_JobName$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_JobName$vtype	*vtype;
	_jc_javax_print_attribute_standard_JobName$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_JobName$vtype _jc_javax_print_attribute_standard_JobName$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_JobName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_JobName$class_object;

#endif	/* _JC_javax_print_attribute_standard_JobName_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/JobName.h <==
// public final class javax.print.attribute.standard.JobName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2c49b1290ea91885 javax_print_attribute_TextSyntax
// @dep_class e749b5922c186449 javax_print_attribute_standard_JobName

// header file dependencies
// @dep_header javax_print_attribute_TextSyntax

#include "javax/print/attribute/TextSyntax.h"

#ifndef _JC_javax_print_attribute_standard_JobName_H_
#define _JC_javax_print_attribute_standard_JobName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_JobName$sub_refs	_jc_javax_print_attribute_standard_JobName$sub_refs;
typedef struct _jc_javax_print_attribute_standard_JobName$sub_nonrefs	_jc_javax_print_attribute_standard_JobName$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobName$refs	_jc_javax_print_attribute_standard_JobName$refs;
typedef struct _jc_javax_print_attribute_standard_JobName$nonrefs	_jc_javax_print_attribute_standard_JobName$nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobName$object	_jc_javax_print_attribute_standard_JobName$object;

typedef struct _jc_javax_print_attribute_standard_JobName$fields_struct	_jc_javax_print_attribute_standard_JobName$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_JobName$vmethods	_jc_javax_print_attribute_standard_JobName$vmethods;
typedef const struct _jc_javax_print_attribute_standard_JobName$vtable	_jc_javax_print_attribute_standard_JobName$vtable;
typedef const struct _jc_javax_print_attribute_standard_JobName$vtype	_jc_javax_print_attribute_standard_JobName$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_JobName$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24JobName;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_JobName$fields_struct _jc_javax_print_attribute_standard_JobName$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_JobName$method$_init$cc9f9d14d2541299(_jc_env *, struct _jc_javax_print_attribute_standard_JobName$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_print_attribute_standard_JobName$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_standard_JobName$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobName$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_JobName$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_JobName$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_JobName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_JobName$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_standard_JobName$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_JobName$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobName$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_JobName$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_standard_JobName$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_JobName$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_JobName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_JobName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_TextSyntax$vmethods	javax_print_attribute_TextSyntax;
	_jc_javax_print_attribute_standard_JobName$vmethods	javax_print_attribute_standard_JobName;
};

// Vtype
struct _jc_javax_print_attribute_standard_JobName$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_JobName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobName$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobName$refs {
    _jc_javax_print_attribute_standard_JobName$sub_refs	javax_print_attribute_standard_JobName;
    _jc_javax_print_attribute_TextSyntax$sub_refs	javax_print_attribute_TextSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_TextSyntax$sub_nonrefs	javax_print_attribute_TextSyntax;
    _jc_javax_print_attribute_standard_JobName$sub_nonrefs	javax_print_attribute_standard_JobName;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_JobName$object {
	_jc_javax_print_attribute_standard_JobName$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_JobName$vtype	*vtype;
	_jc_javax_print_attribute_standard_JobName$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_JobName$vtype _jc_javax_print_attribute_standard_JobName$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_JobName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_JobName$class_object;

#endif	/* _JC_javax_print_attribute_standard_JobName_H_ */
